asr.test.mocks.gpaw.occupations
===============================

.. automodule:: asr.test.mocks.gpaw.occupations

   
   
   .. rubric:: Functions

   
   .. autofunction:: create_occ_calc
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: FermiDirac
      :members:
   
   

   
   
   